@@ -71,6 +71,7 @@ def up(
     session_memory: int,
     envs: Dict,
     labels: Dict,
+    max_rate: float = 0.0,
 ) -> str:
 
     """Create a MarathonApp instance."""
@@ -135,6 +136,7 @@ def up(
         str(duration),
         start_mode,
         str(pause_timeout),
+        str(max_rate)
     ]
 
     marathon_app_definition = MarathonApp(
